import React,{Fragment} from 'react';
import axios from 'axios';
import {Upload, Icon, Modal, message, Form, Select} from 'antd';
import HttpClient from "../../../../service/HttpClient";
import Api from "../../../../service/Api";
export default class ItemUploader extends React.Component{
    constructor(props){
        super(props);
        this.state = {
            previewVisible: false,
            previewImage: '',
            fileList: [],
        }
    }

    componentWillReceiveProps(nextProps, nextContext) {
        if (nextProps.value) {
            this.setState({
                fileList: [
                    {
                        uid: '-1',
                        url: nextProps.value,
                        status: 'done',
                    },
                ],
            })
        }
    }

    beforeUpload=(file)=>{
        if (!file.type === 'image/png' || !file.type === 'image/jpeg') {
            message.error('您上传的文件格式不支持!');
            return false
        }
        const isLt2M = file.size / 1024 / 1024 < 2;
        if (!isLt2M) {
            message.error('请小于2M!');
            return false
        }
        return true;
    };
    handleChange = ({fileList}) => {
        if(fileList.length === 0){
            this.setState({fileList:[]});
            this.props.onChange(undefined);
        }
        this.setState({fileList});
    }
    handleCancel = (e) => {
        this.setState({ previewVisible: false })
    }
    handlePreview = (file) => {
        this.setState({
            previewImage: file.url || file.thumbUrl,
            previewVisible: true,
        });
    };
    customRequest = (option)=> {
        this.getToken({name:option.file.name,type:option.file.type}).then(data =>{
            let param = new FormData(); // 创建form对象
            let fileList = Object.assign([],this.state.fileList);
            param.append('name', option.file.name);// 通过append向form对象添加数据
            param.append('key', data.key);
            param.append('policy', data.policy);
            param.append('OSSAccessKeyId', data.accessid);
            param.append('success_action_status', 200);
            param.append('signature', data.signature);
            param.append('file', option.file, option.file.name);
            let up =  axios.create({
                timeout: 15000,// 请求超时时间
                headers: {
                    'Content-Type': 'multipart/form-data',
                },
            });
            let arr = [];
            up.post(data.host, param).then(response => {
                this.state.fileList =  this.state.fileList.map((item,index)=>{
                    if(option.file.uid === item.uid){
                        return {
                            uid: option.file.uid,
                            name: option.file.name,
                            status: 'done',
                            url: `${data.host}/${data.key}`,
                        }
                    }
                });
                this.setState({
                    fileList:this.state.fileList,
                })
                this.props.onChange(this.state.fileList[0].url);
            }).catch(function (error) {
                message.error('上传失败!',1)
            });
        })
    };
    async getToken(params){
        return await HttpClient.get(Api.upload_token,params);
    }
    componentDidMount() {
    }
    render() {
        const { previewVisible, previewImage, fileList } = this.state;
        const uploadButton = (
            <div>
                <Icon type="plus" />
                <div className="ant-upload-text">上传</div>
            </div>
        );
        return(
            <div className="ctm-clearfix">
                <Upload
                    listType="picture-card"
                    fileList={fileList}
                    beforeUpload={this.beforeUpload}
                    customRequest={this.customRequest}
                    onPreview={this.handlePreview}
                    onChange={this.handleChange}
                >
                        {fileList.length >= 1 ? null : uploadButton}
            </Upload>
            <Modal visible={previewVisible} footer={null} onCancel={this.handleCancel}>
                <img alt="预览" style={{ width: '100%' }} src={previewImage} />
            </Modal>
        </div>
        )
    }
}
